package com.huashe.park.core.service;

import com.huashe.park.domain.entity.ParkInspectTaskUsrTrail;

import java.util.List;

/**
 * 巡检轨迹Service接口
 *
 * @author ruoyi
 * @date 2025-01-07
 */
public interface IParkInspectTaskUsrTrailService {
    /**
     * 查询巡检轨迹
     *
     * @param id 巡检轨迹主键
     * @return 巡检轨迹
     */
    ParkInspectTaskUsrTrail selectParkInspectTaskUsrTrailById(Long id);

    /**
     * 查询巡检轨迹列表
     *
     * @param parkInspectTaskUsrTrail 巡检轨迹
     * @return 巡检轨迹集合
     */
    List<ParkInspectTaskUsrTrail> selectParkInspectTaskUsrTrailList(ParkInspectTaskUsrTrail parkInspectTaskUsrTrail);

    /**
     * 新增巡检轨迹
     *
     * @param parkInspectTaskUsrTrail 巡检轨迹
     * @return 结果
     */
    int insertParkInspectTaskUsrTrail(ParkInspectTaskUsrTrail parkInspectTaskUsrTrail);

    /**
     * 修改巡检轨迹
     *
     * @param parkInspectTaskUsrTrail 巡检轨迹
     * @return 结果
     */
    int updateParkInspectTaskUsrTrail(ParkInspectTaskUsrTrail parkInspectTaskUsrTrail);

    /**
     * 批量删除巡检轨迹
     *
     * @param ids 需要删除的巡检轨迹主键集合
     * @return 结果
     */
    int deleteParkInspectTaskUsrTrailByIds(Long[] ids);

    /**
     * 删除巡检轨迹信息
     *
     * @param id 巡检轨迹主键
     * @return 结果
     */
    int deleteParkInspectTaskUsrTrailById(Long id);
}
